<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de http://www.spip.net/trad-lang/
// ** ne pas modifier le fichier **

if (!defined("_ECRIRE_INC_VERSION")) return;

$GLOBALS[$GLOBALS['idx_lang']] = array(

// 0
'0_URL' => 'http://listes.rezo.net/mailman/listinfo/spip-zh',
'0_langue' => '&#31616;&#20307;&#20013;&#25991; [zh]',
'0_liste' => 'spip-zh@rezo.net',
'0_mainteneur' => 'Lily Zou (lily.zou@terra.com.cn)
Zhen QIN (zhen_q@21cn.com)',

// A
'access_interface_graphique' => '&#36820;&#22238;&#23436;&#25972;&#26174;&#31034;&#27169;&#24335;',
'access_mode_texte' => '&#26174;&#31034;&#31616;&#27905;&#26174;&#31034;&#27169;&#24335;',
'admin_debug' => '&#38500;&#37679;',
'admin_modifier_article' => '&#20462;&#25913;&#25991;&#31456;',
'admin_modifier_auteur' => '&#20462;&#25913;&#20316;&#32773;',
'admin_modifier_breve' => '&#20462;&#25913;&#31616;&#35201;',
'admin_modifier_mot' => '&#20462;&#25913;&#20851;&#38190;&#35789;',
'admin_modifier_rubrique' => '&#20462;&#25913;&#27492;&#26639;',
'admin_recalculer' => '&#21047;&#26032;&#39029;&#38754;',
'afficher_trad' => '&#26174;&#31034;&#35793;&#25991;',
'alerte_maj_impossible' => '<b>&#35686;&#21578;!</b> &#26356;&#26032;SQL&#21040;&#29256;&#26412; @version@&#22833;&#36133;, &#21487;&#33021;&#26159;&#25968;&#25454;&#24211;&#26435;&#38480;&#38382;&#39064;. &#35831;&#32852;&#31995;&#24744;&#30340;ISP(INTERNET&#26381;&#21153;&#25552;&#20379;&#21830;) .', # MODIF
'alerte_modif_info_concourante' => '&#27880;&#24847;:&#36825;&#26465;&#20449;&#24687;&#22312;&#21035;&#22788;&#34987;&#26356;&#25913;&#12290;&#30446;&#21069;&#20540;&#20026;&nbsp;:', # MODIF
'analyse_xml' => 'XML&#20998;&#26512;',
'annuler' => '&#21462;&#28040;',
'antispam_champ_vide' => '&#35831;&#20445;&#30041;&#27492;&#26684;&#31354;&#30333;:',
'articles_recents' => '&#26368;&#26032;&#25991;&#31456;',
'avis_archive_incorrect' => '&#25171;&#21253;&#25991;&#20214;&#19981;&#26159;&#26377;&#25928;&#30340;SPIP&#25991;&#20214;',
'avis_archive_invalide' => '&#25171;&#21253;&#25991;&#20214;&#26080;&#25928;',
'avis_attention' => '&#27880;&#24847;!',
'avis_champ_incorrect_type_objet' => '&#26080;&#25928;&#21517; @name@ &#23545;&#35937;&#21517; @type@',
'avis_colonne_inexistante' => ' @col@ &#21015;&#19981;&#23384;&#22312;',
'avis_echec_syndication_01' => '&#32852;&#21512;&#22833;&#36133;: &#35201;&#20040;&#26159;&#36873;&#25321;&#30340;&#31105;&#27490;&#35835;,&#35201;&#20040;&#23427;&#19981;&#25552;&#20379;&#20219;&#20309;&#25991;&#31456;.',
'avis_echec_syndication_02' => '&#32852;&#21512;&#22833;&#36133;: &#19981;&#33021;&#21040;&#36798;&#31449;&#28857;&#30340;&#38459;&#27490;&#21306;.',
'avis_erreur' => '&#38169;&#35823;: &#21442;&#35265;&#20197;&#19979;',
'avis_erreur_connexion' => '&#36830;&#25509;&#22833;&#36133;',
'avis_erreur_cookie' => 'cookie&#38169;&#35823;',
'avis_erreur_fonction_contexte' => '&#31243;&#24207;&#22833;&#36133;. &#35813;&#21151;&#33021;&#19981;&#33021;&#22312;&#27492;&#35843;&#29992;.', # MODIF
'avis_erreur_mysql' => 'SQL&#38169;&#35823;', # MODIF
'avis_erreur_sauvegarde' => '@type@ @id_objet@&#22791;&#20221;&#22833;&#36133;!',
'avis_erreur_visiteur' => '&#35775;&#38382;&#20010;&#20154;&#31354;&#38388;&#20986;&#38169;',

// B
'barre_a_accent_grave' => '&#25554;&#20837;&#21152;&#37325;&#30340;&#23383;&#31526;',
'barre_aide' => '&#29992;&#35937;&#24449;&#22270;&#24555;&#25463;&#23450;&#20041;&#23637;&#20986;',
'barre_e_accent_aigu' => '&#25554;&#20837;&#21152;&#37325;&#30340;E ',
'barre_eo' => '&#25554;&#20837;oe [&#27861;&#25991;&#36755;&#20837;]',
'barre_eo_maj' => '&#22312;O&#20043;&#21518;&#25554;&#20837;E[&#27861;&#25991;OE&#36755;&#20837;]',
'barre_euro' => '&#25554;&#20837;&#27431;&#20803;&#26631;&#24535;&euro;',
'barre_gras' => '&#32622;&#20026;{{&#40657;&#20307;}}',
'barre_guillemets' => '&#21152;&#21452;&#24341;&#21495;',
'barre_guillemets_simples' => '&#21152;&#21333;&#24341;&#21495;',
'barre_intertitre' => '&#36716;&#20026;{{{&#23567;&#26631;&#39064;}}}',
'barre_italic' => '&#32622;&#20026;{&#26012;&#20307;}',
'barre_lien' => '&#36716;&#20026;&#36229;&#25991;&#26412;&#38142;&#25509;[http://...]',
'barre_lien_input' => '&#35831;&#36755;&#20837;&#30446;&#26631;&#38142;&#25509;(&#24744;&#21487;&#20197;&#20351;&#29992; http://www.mysite.com&#30340;&#26684;&#24335;&#25110;&#30452;&#25509;&#25351;&#20986;&#22312;&#26412;&#31449;&#20013;&#35813;&#25991;&#31456;&#30340;&#32534;&#21495;).',
'barre_note' => '&#36716;&#20026;[[&#39029;&#23614;&#26631;&#21495;]]',
'barre_paragraphe' => '<modif>&#26032;&#24314;&#27573;&#33853;',
'barre_quote' => '<quote>&#24341;&#29992;&#19968;&#20010;&#28040;&#24687;</quote>',
'bouton_ajouter_document' => '&#28155;&#21152;&#25991;&#26723;', # MODIF
'bouton_ajouter_image' => '&#28155;&#21152;&#22270;&#29255;', # MODIF
'bouton_ajouter_image_document' => '&#28155;&#21152;&#22270;&#29255;&#25110;&#25991;&#20214;',
'bouton_changer' => '&#20462;&#25913;',
'bouton_chercher' => '&#25628;&#32034;',
'bouton_choisir' => '&#36873;&#25321;',
'bouton_download' => 'T&eacute;l&eacute;charger', # NEW
'bouton_enregistrer' => '&#20445;&#23384;',
'bouton_radio_desactiver_messagerie_interne' => '&#20572;&#29992;&#20869;&#37096;&#28040;&#24687;',
'bouton_radio_envoi_annonces' => '&#21457;&#36865;&#21487;&#32534;&#36753;&#30340;&#22768;&#26126;',
'bouton_radio_non_envoi_annonces' => '&#19981;&#20351;&#29992;&#20219;&#20309;&#22768;&#26126;',
'bouton_radio_non_envoi_liste_nouveautes' => '&#19981;&#21457;&#36865;&#26368;&#36817;&#26032;&#38395;&#21015;&#34920;',
'bouton_recharger_page' => '&#37325;&#36733;&#26412;&#39029;',
'bouton_telecharger' => '&#19978;&#20256;',
'bouton_valider' => '&#25552;&#20132;',

// C
'cal_apresmidi' => '&#19979;&#21320;',
'cal_jour_entier' => '&#25972;&#26085;',
'cal_matin' => '&#26089;&#26216;',
'cal_par_jour' => '&#25353;&#26085;&#26174;&#31034;&#26085;&#31243;',
'cal_par_mois' => '&#25353;&#26376;&#26174;&#31034;&#26085;&#31243;',
'cal_par_semaine' => '&#25353;&#21608;&#26174;&#31034;&#26085;&#31243;',
'choix_couleur_interface' => '&#39068;&#33394;',
'choix_interface' => '<modif>&#30028;&#38754;&#20999;&#25442;',
'colonne' => '&#21015;',
'confirm_changer_statut' => '&#27880;&#24847;&#65292;&#24744;&#35201;&#27714;&#25913;&#21464;&#36825;&#19968;&#39033;&#30446;&#30340;&#29366;&#24577;&#12290;&#35831;&#30830;&#35748;&#32487;&#32493;&#12290;',
'correcte' => '<modif>&#29983;&#25928;',

// D
'date_aujourdhui' => '&#20170;&#22825;',
'date_avant_jc' => '&#20844;&#20803;&#21069;',
'date_dans' => '&#22312; @delai@&#20043;&#20869;&#12290;',
'date_de_mois_1' => '@nommois@@j@&#26085;',
'date_de_mois_10' => '@nommois@@j@&#26085;',
'date_de_mois_11' => '@nommois@@j@&#26085;',
'date_de_mois_12' => '@nommois@@j@&#26085;',
'date_de_mois_2' => '@nommois@@j@&#26085;',
'date_de_mois_3' => '@nommois@@j@&#26085;',
'date_de_mois_4' => '@nommois@@j@&#26085;',
'date_de_mois_5' => '@nommois@@j@&#26085;',
'date_de_mois_6' => '@nommois@@j@&#26085;',
'date_de_mois_7' => '@nommois@@j@&#26085;',
'date_de_mois_8' => '@nommois@@j@&#26085;',
'date_de_mois_9' => '@nommois@@j@&#26085;',
'date_demain' => '&#26126;&#22825;',
'date_fmt_heures_minutes' => '@h@:@m@',
'date_fmt_jour_heure' => '@jour@@heure@&#26102;',
'date_fmt_jour_mois' => '@nommois@@jour@&#26085;',
'date_fmt_jour_mois_annee' => '@annee@&#24180;@nommois@@jour@&#26085;',
'date_fmt_mois_annee' => '@annee@&#24180;@nommois@',
'date_fmt_nomjour_date' => '@nomjour@ &#26085;@date@',
'date_heures' => '&#23567;&#26102;',
'date_hier' => '&#26152;&#22825;',
'date_il_y_a' => ' @delai@&#20197;&#21069;',
'date_jnum1' => '1',
'date_jnum10' => '10',
'date_jnum11' => '11',
'date_jnum12' => '12',
'date_jnum13' => '13',
'date_jnum14' => '14',
'date_jnum15' => '15',
'date_jnum16' => '16',
'date_jnum17' => '17',
'date_jnum18' => '18',
'date_jnum19' => '19',
'date_jnum2' => '2',
'date_jnum20' => '20',
'date_jnum21' => '21',
'date_jnum22' => '22',
'date_jnum23' => '23',
'date_jnum24' => '24',
'date_jnum25' => '25',
'date_jnum26' => '26',
'date_jnum27' => '27',
'date_jnum28' => '28',
'date_jnum29' => '29',
'date_jnum3' => '3',
'date_jnum30' => '30',
'date_jnum31' => '31',
'date_jnum4' => '4',
'date_jnum5' => '5',
'date_jnum6' => '6',
'date_jnum7' => '7',
'date_jnum8' => '8',
'date_jnum9' => '9',
'date_jour_1' => '&#26143;&#26399;&#26085;',
'date_jour_1_abbr' => '<modif>&#21608;&#26085;',
'date_jour_1_initiale' => '&#26143;&#26399;&#22825;',
'date_jour_2' => '&#26143;&#26399;&#19968;',
'date_jour_2_abbr' => '<modif>&#26143;&#26399;&#19968;',
'date_jour_2_initiale' => 'l.',
'date_jour_3' => '&#26143;&#26399;&#20108;',
'date_jour_3_abbr' => '&#26143;&#26399;&#20108;',
'date_jour_3_initiale' => 'm.', # NEW
'date_jour_4' => '&#26143;&#26399;&#19977;',
'date_jour_4_abbr' => 'mer.', # NEW
'date_jour_4_initiale' => 'm.', # NEW
'date_jour_5' => '&#26143;&#26399;&#22235;',
'date_jour_5_abbr' => 'jeu.', # NEW
'date_jour_5_initiale' => 'j.', # NEW
'date_jour_6' => '&#26143;&#26399;&#20116;',
'date_jour_6_abbr' => 'ven.', # NEW
'date_jour_6_initiale' => 'v.', # NEW
'date_jour_7' => '&#26143;&#26399;&#20845;',
'date_jour_7_abbr' => 'sam.', # NEW
'date_jour_7_initiale' => 's.', # NEW
'date_jours' => '&#22825;',
'date_minutes' => '&#20998;&#38047;',
'date_mois' => '&#26376;',
'date_mois_1' => '1&#26376;',
'date_mois_10' => '10&#26376;',
'date_mois_11' => '11&#26376;',
'date_mois_12' => '12&#26376;',
'date_mois_2' => '2&#26376;',
'date_mois_3' => '3&#26376;',
'date_mois_4' => '4&#26376;',
'date_mois_5' => '5&#26376;',
'date_mois_6' => '6&#26376;',
'date_mois_7' => '7&#26376;',
'date_mois_8' => '8&#26376;',
'date_mois_9' => '9&#26376;',
'date_saison_1' => '&#20908;&#23395;',
'date_saison_2' => '&#26149;&#23395;',
'date_saison_3' => '&#22799;&#23395;',
'date_saison_4' => '&#31179;&#23395;',
'date_secondes' => 'secondes', # NEW
'date_semaines' => '&#21608;',
'date_un_mois' => '<NEW>&#26376;',
'date_une_heure' => 'heure', # NEW
'date_une_minute' => 'minute', # NEW
'date_une_seconde' => 'seconde', # NEW
'date_une_semaine' => 'semaine', # NEW
'dirs_commencer' => '&#20026;&#20102;&#24320;&#22987;&#23433;&#35013;',
'dirs_preliminaire' => '&#21021;&#27493;: <b>&#35774;&#32622;&#35775;&#38382;&#26435;&#38480;</b>',
'dirs_probleme_droits' => '&#35775;&#38382;&#26435;&#38480;&#38382;&#39064;', # MODIF
'dirs_repertoires_absents' => '<b>&#26410;&#25214;&#21040;&#19979;&#21015;&#30446;&#24405;: <ul>@bad_dirs@.</ul> </b>
  <p>&#21487;&#33021;&#30001;&#20110;&#36755;&#20837;&#22823;&#23567;&#20889;&#26377;&#35823;.
  &#35831;&#30830;&#35748;&#30446;&#24405;&#30340;&#22823;&#23567;&#20889;&#27491;&#30830;; &#22914;&#26524;&#19981;&#27491;&#30830;, &#21487;&#36890;&#36807;FTP&#36719;&#20214;&#20462;&#25913;&#30446;&#24405;&#21517;&#23383;&#20197;&#32416;&#38169;.
  <p>&#19968;&#26086;&#23436;&#25104;,&#24744;&#21487;&#20197;', # MODIF
'dirs_repertoires_suivants' => '<b>&#20197;&#19979;&#30446;&#24405;&#26080;&#20889;&#26435;&#38480;: <ul>@bad_dirs@.</ul> </b>

  <p>&#20462;&#25913;&#26435;&#38480;&#35831;&#20351;&#29992;FTP&#23458;&#25143;&#31471;&#20026;&#27599;&#20010;&#30446;&#24405;&#35774;&#23450;&#35775;&#38382;&#26435;&#38480;. &#35813;&#25805;&#20316;&#22312;&#29992;&#25143;&#25351;&#21335;&#20013;&#26377;&#35814;&#32454;&#20171;&#32461;.

  <p>&#19968;&#26086;&#23436;&#25104;,&#24744;&#21487;&#20197;', # MODIF
'double_occurrence' => 'Double occurrence', # MODIF

// E
'en_cours' => 'en cours', # NEW
'entree_dimensions' => '&#22823;&#23567;:',
'entree_titre_document' => '&#25991;&#20214;&#26631;&#39064;:',
'entree_titre_image' => '&#22270;&#20687;&#26631;&#39064;:',
'envoi_via_le_site' => '&#36890;&#36807;&#26412;&#32593;&#31449;&#21457;&#36865;',
'erreur' => 'Erreur', # NEW
'erreur_balise_non_fermee' => 'derni&egrave;re balise non referm&eacute;e :', # NEW
'erreur_texte' => 'erreur(s)', # NEW
'etape' => '&Eacute;tape', # NEW

// F
'fichier_introuvable' => '&#25214;&#19981;&#21040;@fichier@&#25991;&#20214;',
'form_auteur_confirmation' => 'Confirmez votre adresse email', # NEW
'form_auteur_email_modifie' => 'Votre adresse email a &eacute;t&eacute; modifi&eacute;e.', # NEW
'form_auteur_envoi_mail_confirmation' => 'Un courrier &eacute;lectronique de confirmation vient d\'&ecirc;tre envoy&eacute; &agrave; @email@. Vous devrez visiter l\'adresse Web mentionn&eacute;e dans ce courrier pour valider votre adresse mail.', # NEW
'form_auteur_mail_confirmation' => 'Bonjour,

Vous avez demand&eacute; &agrave; changer votre adresse email.
Pour confirmer votre nouvelle adresse, il suffit de vous connecter &agrave;
l\'adresse ci-dessous (dans le cas contraire, votre demande
sera ignor&eacute;e) :

    @url@
', # NEW
'form_deja_inscrit' => '&#24744;&#24050;&#27880;&#20876;.',
'form_email_non_valide' => '&#24744;&#30340;&#30005;&#23376;&#37038;&#20214;&#26080;&#25928;.',
'form_forum_access_refuse' => '&#24744;&#26080;&#26435;&#32487;&#32493;&#35775;&#38382;&#35813;&#31449;&#28857;.',
'form_forum_bonjour' => '<MODIF>&#24744;&#22909;@nom@&#65292;',
'form_forum_email_deja_enregistre' => '&#35813;&#30005;&#23376;&#37038;&#20214;&#22320;&#22336;&#24050;&#32463;&#35760;&#24405;,&#24744;&#21487;&#20197;&#20351;&#29992;&#24120;&#29992;&#23494;&#30721;.',
'form_forum_identifiant_mail' => '&#24744;&#30340;&#26032;&#26631;&#35782;&#24050;&#32463;&#36890;&#36807;&#37038;&#20214;&#21457;&#36865;&#32473;&#24744;&#20102;.',
'form_forum_identifiants' => '&#20010;&#20154;&#26631;&#35782;&#31526;',
'form_forum_indiquer_nom_email' => '&#36755;&#20837;&#24744;&#30340;&#21517;&#23383;&#21644;&#30005;&#23376;&#37038;&#20214;&#22320;&#22336;,&#24744;&#23558;&#24456;&#24555;&#36890;&#36807;&#30005;&#23376;&#37038;&#20214;&#33719;&#21462;&#24744;&#30340;&#20010;&#20154;&#26631;&#35782;&#31526;.',
'form_forum_login' => '&#30331;&#24405;:',
'form_forum_message_auto' => '(&#36825;&#26159;&#33258;&#21160;&#28040;&#24687;)',
'form_forum_pass' => '&#23494;&#30721;:',
'form_forum_probleme_mail' => '&#37038;&#20214;&#38382;&#39064;: &#26631;&#35782;&#31526;&#19981;&#33021;&#34987;&#21457;&#36865;.',
'form_forum_voici1' => '<MODIF>&#36825;&#26159;&#24744;&#21152;&#20837;&#31449;&#28857;&#32593;&#31449;&#32534;&#36753;&#21644;&#35770;&#22363;&#30340;&#26631;&#35782;&#31526;
"@nom_site_spip@" (@adresse_site@):',
'form_forum_voici2' => '&#36825;&#26159;&#24744;&#25552;&#20132;&#25991;&#31456;&#30340;&#26631;&#35782;&#31526;
 "@nom_site_spip@" (@adresse_login@):', # MODIF
'form_indiquer_email' => '&#35831;&#36755;&#20837;&#24744;&#30340;&#30005;&#23376;&#37038;&#20214;&#22320;&#22336;.',
'form_indiquer_nom' => '&#35831;&#36755;&#20837;&#24744;&#30340;&#21517;&#23383;.',
'form_indiquer_nom_site' => '&#35831;&#36755;&#20837;&#24744;&#30340;&#31449;&#28857;&#21517;&#23383;.',
'form_pet_adresse_site' => '&#31449;&#28857;&#38142;&#25509;',
'form_pet_aucune_signature' => '&#27809;&#26377;&#19982;&#35813;&#20195;&#30721;&#21305;&#37197;&#30340;&#31614;&#21517;...',
'form_pet_confirmation' => '&#35831;&#30830;&#23450;&#31614;&#21517;:',
'form_pet_deja_enregistre' => '&#31449;&#28857;&#24050;&#32463;&#27880;&#20876;',
'form_pet_deja_signe' => '&#24744;&#24050;&#32463;&#31614;&#32626;&#35813;&#25991;.',
'form_pet_envoi_mail_confirmation' => '&#19968;&#23553;&#30830;&#35748;&#20449;&#24050;&#32463;&#21457;&#36865;&#32473;&#24744;,&#35831;&#35775;&#38382;&#37038;&#20214;&#20013;&#30340;&#38142;&#25509;&#30830;&#35748;&#24744;&#30340;&#31614;&#21517;.', # MODIF
'form_pet_mail_confirmation' => '&#24744;&#22909;,

&#24744;&#35201;&#27714;&#22312;&#35831;&#27714;:@titre@&#19978;&#31614;&#21517;.

&#24744;&#25552;&#20379;&#20102;&#20197;&#19979;&#20449;&#24687;:
    &#22995;&#21517;: @nom_email@
    &#31449;&#28857;: @nom_site@ - @url_site@

&#37325;&#35201;...
&#30830;&#35748;&#24744;&#30340;&#31614;&#21517;&#21482;&#38656;&#35775;&#38382;&#20197;&#19979;&#22320;&#22336; (&#21542;&#21017;, &#24744;&#30340;&#35831;&#27714;&#23558;&#34987;&#25298;&#32477;):
    @url@

&#24863;&#35874;&#24744;&#30340;&#21442;&#19982;
', # MODIF
'form_pet_message_commentaire' => '&#20854;&#23427;&#28040;&#24687;&#21644;&#35780;&#35770;?',
'form_pet_nom_site2' => '&#24744;&#30340;&#31449;&#28857;&#21517;',
'form_pet_probleme_liens' => 'Veuillez reprendre votre message en supprimant les liens hypertexte.', # NEW
'form_pet_probleme_technique' => '&#25216;&#26415;&#38382;&#39064;,&#31614;&#21517;&#34987;&#21363;&#21051;&#20013;&#26029;.',
'form_pet_signature_pasprise' => '&#31614;&#21517;&#34987;&#24573;&#30053;.',
'form_pet_signature_validee' => '&#24744;&#30340;&#31614;&#21517;&#26377;&#25928;,&#31449;&#28857;&#26356;&#26032;&#21518;&#23558;&#26174;&#31034;.&#35874;&#35874;!', # MODIF
'form_pet_site_deja_enregistre' => '&#31449;&#28857;&#24050;&#32463;&#27880;&#20876;',
'form_pet_url_invalide' => '&#24744;&#36755;&#20837;&#30340;URL&#26080;&#25928;.',
'form_pet_votre_email' => '&#24744;&#30340;&#30005;&#23376;&#37038;&#20214;&#22320;&#22336;',
'form_pet_votre_nom' => '&#24744;&#30340;&#21517;&#23383;&#25110;&#26165;&#31216;',
'form_pet_votre_site' => '&#22914;&#26524;&#24744;&#26377;&#20010;&#20154;&#32593;&#31449;,&#24744;&#21487;&#20197;&#22312;&#19979;&#38754;&#36755;&#20837;',
'form_prop_confirmer_envoi' => '&#30830;&#35748;&#21457;&#36865;',
'form_prop_description' => '&#25551;&#36848;/&#27880;&#37322;',
'form_prop_enregistre' => '&#20320;&#30340;&#25552;&#35758;&#24050;&#32463;&#34987;&#35760;&#24405;, &#31449;&#28857;&#31649;&#29702;&#21592;&#20351;&#23427;&#26377;&#25928;&#23427;&#23558;&#22312;&#32447;&#26174;&#31034;.',
'form_prop_envoyer' => '&#21457;&#36865;&#28040;&#24687;',
'form_prop_indiquer_email' => '&#35831;&#36755;&#20837;&#26377;&#25928;&#30340;&#30005;&#23376;&#37038;&#20214;&#22320;&#22336;',
'form_prop_indiquer_nom_site' => '&#35831;&#36755;&#20837;&#31449;&#28857;&#21517;',
'form_prop_indiquer_sujet' => '&#35831;&#36755;&#20837;&#26631;&#39064;',
'form_prop_message_envoye' => '&#28040;&#24687;&#21457;&#36865;',
'form_prop_nom_site' => '&#31449;&#28857;&#21517;',
'form_prop_non_enregistre' => '&#24744;&#30340;&#25552;&#35758;&#26410;&#34987;&#35760;&#24405;.',
'form_prop_sujet' => '&#26631;&#39064;',
'form_prop_url_site' => '&#31449;&#28857;URL',
'forum_acces_refuse' => '&#24744;&#24050;&#32463;&#26080;&#26435;&#35775;&#38382;&#36825;&#20123;&#35770;&#22363;.',
'forum_attention_dix_caracteres' => '<b>&#35686;&#21578;!</b> &#24744;&#30340;&#28040;&#24687;&#23569;&#20110;&#21313;&#20010;&#23383;&#31526;.', # MODIF
'forum_attention_trois_caracteres' => '<b>&#35686;&#21578;!</b> &#24744;&#30340;&#26631;&#39064;&#23569;&#20110;&#19977;&#20010;&#23383;&#31526;.', # MODIF
'forum_attention_trop_caracteres' => '<b>Attention&nbsp;!</b> votre message est trop long (@compte@ caract&egrave;res)&nbsp;: pour pouvoir &ecirc;tre enregistr&eacute;, il ne doit pas d&eacute;passer @max@ caract&egrave;res.', # NEW
'forum_avez_selectionne' => '&#24744;&#24050;&#36873;&#25321;:',
'forum_cliquer_retour' => '&#21333;&#20987;  <a href=\'@retour_forum@\'>&#36825;&#37324;</a> &#32487;&#32493;.',
'forum_forum' => '&#35770;&#22363;',
'forum_info_modere' => '&#35770;&#22363;&#26159;&#39044;&#32531;&#20914;&#30340;: &#24744;&#30340;&#25237;&#31295;&#21482;&#26377;&#34987;&#31449;&#28857;&#31649;&#29702;&#21592;&#30830;&#35748;&#25165;&#33021;&#26174;&#31034;.',
'forum_lien_hyper' => '<MODIF><b>&#36229;&#38142;&#25509;</b> (&#21487;&#36873;)',
'forum_message_definitif' => '&#26368;&#21518;&#28040;&#24687;: &#21457;&#36865;&#21040;&#31449;&#28857;',
'forum_message_trop_long' => '&#24744;&#30340;&#28040;&#24687;&#36807;&#38271;. &#26368;&#22823;&#38271;&#24230;&#20026;20000&#20010;&#23383;&#31526;.',
'forum_ne_repondez_pas' => '&#35831;&#21247;&#22238;&#22797;&#35813;&#20449;&#20214;,&#35831;&#21040;&#22914;&#19979;&#22320;&#22336;&#30340;&#35770;&#22363;&#22238;&#22797;:',
'forum_non_inscrit' => '&#21487;&#33021;&#24744;&#36824;&#27809;&#26377;&#27880;&#20876;&#25110;&#32773;&#24744;&#36755;&#20837;&#30340;&#22320;&#22336;&#25110;&#23494;&#30721;&#38169;&#35823;.',
'forum_page_url' => '(&#22914;&#26524;&#24744;&#30340;&#28040;&#24687;&#24341;&#29992;&#20102;web&#19978;&#21457;&#34920;&#30340;&#25991;&#31456;&#35831;&#25552;&#20379;&#36827;&#19968;&#27493;&#30340;&#28040;&#24687;, &#35831;&#36755;&#20837;&#39029;&#22836;&#21644;&#23427;&#30340;URL).', # MODIF
'forum_par_auteur' => '&#25353; @auteur@',
'forum_poste_par' => '&#24744;&#25991;&#31456;@parauteur@&#20043;&#21518;&#21518;&#21457;&#34920;&#30340;&#20449;&#24687;.', # MODIF
'forum_probleme_database' => '&#25968;&#25454;&#24211;&#38382;&#39064;,&#24744;&#30340;&#28040;&#24687;&#26410;&#33021;&#20445;&#23384;.',
'forum_qui_etes_vous' => '<b>&#24744;&#26159;&#35841;?</b> (&#21487;&#36873;)', # MODIF
'forum_texte' => '&#28040;&#24687;&#27491;&#25991;:',
'forum_titre' => '&#26631;&#39064;:',
'forum_titre_erreur' => '&#38169;&#35823;...',
'forum_url' => 'URL:',
'forum_valider' => '&#20351;&#36873;&#25321;&#29983;&#25928;',
'forum_voir_avant' => '&#21457;&#34920;&#21069;&#39044;&#35272;',
'forum_votre_email' => '&#24744;&#30340;&#37038;&#20214;&#22320;&#22336;:',
'forum_votre_nom' => '&#24744;&#30340;&#21517;&#23383;(&#25110;&#26165;&#31216;):',
'forum_vous_enregistrer' => '&#22312;&#21442;&#19982;&#35770;&#22363;&#21069;,&#24744;&#24517;&#39035;&#27880;&#20876;. &#35874;&#35874;&#24744;&#22635;&#20889;&#24050;&#32463;&#36882;&#20132;&#36807;&#30340;&#20010;&#20154;&#20449;&#24687;.
&#22914;&#26524;&#20320;&#24744;&#23578;&#26410;&#27880;&#20876;, &#24744;&#24517;&#39035;',
'forum_vous_inscrire' => '&#35831;&#27880;&#20876;&#12290;',

// I
'ical_texte_rss_articles' => '&#26412;&#31449;&#28857;&#25991;&#31456;&#30340;&laquo;&#24341;&#29992;&raquo;&#25991;&#20214;&#22320;&#22336;:',
'ical_texte_rss_articles2' => '&#24744;&#21516;&#26679;&#21487;&#20197;&#33719;&#24471;&#31449;&#28857;&#20013;&#21508;&#20010;&#19987;&#26639;&#19979;&#25991;&#31456;&#30340;&laquo;&#24341;&#29992;&raquo;&#25991;&#20214;:',
'ical_texte_rss_breves' => '&#23384;&#22312;&#22810;&#20010;&#31449;&#28857;&#31616;&#35201;&#30340;&#25991;&#20214;.&#36890;&#36807;&#25351;&#20986;&#19987;&#26639;&#32534;&#21495;,&#24744;&#21487;&#20197;&#33719;&#24471;&#20165;&#19982;&#35813;&#19987;&#26639;&#30456;&#20851;&#30340;&#31616;&#35201;.',
'icone_a_suivre' => '&#36319;&#36394;',
'icone_admin_site' => '&#31449;&#28857;&#31649;&#29702;',
'icone_agenda' => '&#35760;&#20107;',
'icone_aide_ligne' => '<MODIF>&#24110;&#21161;',
'icone_articles' => '&#25991;&#31456;',
'icone_auteurs' => '&#20316;&#32773;',
'icone_breves' => '&#31616;&#35201;',
'icone_brouteur' => '&#24555;&#36895;&#27983;&#35272;',
'icone_configuration_site' => '<MODIF>&#37197;&#32622;',
'icone_configurer_site' => '&#37197;&#32622;&#31449;&#28857;',
'icone_creer_nouvel_auteur' => '&#26032;&#24314;&#19968;&#20010;&#20316;&#32773;',
'icone_creer_rubrique' => '&#26032;&#24314;&#19987;&#26639;',
'icone_creer_sous_rubrique' => '&#26032;&#24314;&#23376;&#19987;&#26639;',
'icone_deconnecter' => '&#26029;&#24320;&#36830;&#25509;',
'icone_discussions' => '&#35752;&#35770;',
'icone_doc_rubrique' => '&#21508;&#19987;&#26639;&#25991;&#26723;',
'icone_ecrire_article' => '&#20889;&#26032;&#25991;&#31456;',
'icone_edition_site' => '<MODIF>&#32534;&#36753;',
'icone_forum_administrateur' => '&#31649;&#29702;&#21592;&#35770;&#22363;',
'icone_forum_suivi' => '&#36319;&#36394;&#35770;&#22363;',
'icone_gestion_langues' => '&#35821;&#35328;&#31649;&#29702;',
'icone_informations_personnelles' => '&#20010;&#20154;&#20449;&#24687;',
'icone_interface_complet' => '&#23436;&#25972;&#30028;&#38754;',
'icone_interface_simple' => '&#31616;&#21333;&#30028;&#38754;',
'icone_maintenance_site' => '&#31449;&#28857;&#32500;&#25252;',
'icone_messagerie_personnelle' => '&#20010;&#20154;&#28040;&#24687;',
'icone_mots_cles' => '&#20851;&#38190;&#35789;',
'icone_nouvelle_breve' => '&#20889;&#26032;&#31616;&#35201;',
'icone_repartition_actuelle' => '&#26174;&#31034;&#23454;&#38469;&#20998;&#24067;',
'icone_repartition_debut' => '&#26174;&#31034;&#20174;&#24320;&#22987;&#30340;&#20998;&#24067;',
'icone_repartition_visites' => '&#35775;&#38382;&#20998;&#24067;',
'icone_rubriques' => '&#19987;&#26639;',
'icone_sauver_site' => '&#31449;&#28857;&#22791;&#20221;',
'icone_site_entier' => '&#25972;&#20010;&#31449;&#28857;',
'icone_sites_references' => '&#21442;&#32771;&#31449;&#28857;',
'icone_statistiques' => '&#31449;&#28857;&#32479;&#35745;',
'icone_statistiques_visites' => '&#35775;&#38382;&#32479;&#35745;', # MODIF
'icone_suivi_activite' => '&#36319;&#36394;&#31449;&#28857;&#30340;&#27963;&#21160;',
'icone_suivi_actualite' => '&#31449;&#28857;&#35780;&#20272;',
'icone_suivi_forums' => '&#36319;&#36394;/&#31649;&#29702;&#35770;&#22363;',
'icone_suivi_pettions' => '&#36319;&#36394;/&#31649;&#29702;&#35831;&#27714;',
'icone_suivi_revisions' => '&#25991;&#31456;&#20462;&#25913;',
'icone_supprimer_document' => '&#21024;&#38500;&#25991;&#26723;',
'icone_supprimer_image' => '&#21024;&#38500;&#22270;&#29255;',
'icone_supprimer_message' => '&#21024;&#38500;&#28040;&#24687;',
'icone_tous_articles' => '&#24744;&#25152;&#26377;&#30340;&#25991;&#31456;',
'icone_tous_auteur' => '&#25152;&#26377;&#20316;&#32773;',
'icone_valider_message' => '&#20351;&#28040;&#24687;&#26377;&#25928;',
'icone_visiter_site' => '<MODIF>&#35775;&#38382;',
'icone_voir_en_ligne' => '&#22312;&#32447;&#39044;&#35272;',
'image_tourner_180' => '&#26059;&#36716;180&deg;',
'image_tourner_droite' => '&#21521;&#21491;&#26059;&#36716;90&deg; ',
'image_tourner_gauche' => '&#21521;&#24038;&#26059;&#36716; 90&deg;',
'img_indisponible' => '&#24517;&#38656;&#22270;&#20687;',
'impossible' => 'impossible', # NEW
'info_a_suivre' => '&#36319;&#36394;&nbsp;&raquo;',
'info_a_valider' => '[&#20351;&#26377;&#25928;]',
'info_acces_interdit' => '&#35775;&#38382;&#31105;&#27490;',
'info_acces_refuse' => '&#35775;&#38382;&#25298;&#32477;',
'info_action' => '&#21160;&#20316;: @action@',
'info_administrer_rubriques' => '&#24744;&#21487;&#20197;&#31649;&#29702;&#35813;&#19987;&#26639;&#21450;&#20854;&#23376;&#19987;&#26639;',
'info_adresse_non_indiquee' => '&#24744;&#27809;&#26377;&#25351;&#23450;&#27979;&#35797;&#22320;&#22336;!',
'info_aide' => '&#24110;&#21161;:',
'info_ajouter_mot' => '&#28155;&#21152;&#20851;&#38190;&#35789;',
'info_annonce' => '&#22768;&#26126;',
'info_annonces_generales' => '&#19968;&#33324;&#22768;&#26126;:',
'info_article_propose' => '&#24050;&#25552;&#20132;&#30340;&#25991;&#31456;',
'info_article_publie' => '&#24050;&#21457;&#34920;&#30340;&#25991;&#31456;',
'info_article_redaction' => '&#36827;&#23637;&#20013;&#30340;&#25991;&#31456;',
'info_article_refuse' => '&#20002;&#24323;&#30340;&#25991;&#31456;',
'info_article_supprime' => '&#21024;&#38500;&#30340;&#25991;&#31456;',
'info_articles' => '&#25991;&#31456;',
'info_articles_a_valider' => '&#38656;&#35201;&#30830;&#35748;&#30340;&#25991;&#31456;',
'info_articles_nb' => '@nb@ articles', # NEW
'info_articles_proposes' => '&#25552;&#20132;&#30340;&#25991;&#31456;',
'info_articles_un' => '1 article', # NEW
'info_auteurs_nombre' => '&#20316;&#32773;:',
'info_authentification_ftp' => '(&#36890;&#36807; FTP)&#39564;&#35777;.',
'info_bloquer_lien' => '&#38459;&#27490;&#36825;&#20010;&#36830;&#25509;',
'info_breves_02' => '&#31616;&#35201;',
'info_breves_2' => '&#31616;&#35201;',
'info_breves_nb' => '@nb@ br&egrave;ves', # NEW
'info_breves_un' => '1 br&egrave;ve', # NEW
'info_breves_valider' => '&#38656;&#30830;&#35748;&#30340;&#31616;&#35201;',
'info_connexion_refusee' => '&#36830;&#25509;&#31105;&#27490;',
'info_contact_developpeur' => '&#35831;&#32852;&#31995;&#24320;&#21457;&#32773;.',
'info_contenance' => '&#31449;&#28857;&#21253;&#25324;:',
'info_contribution' => '&#35770;&#22363;&#25237;&#31295;',
'info_copyright' => '@spip@&#26159;&#19968;&#27454;&#20813;&#36153;&#36719;&#20214;@lien_gpl@&#12290;',
'info_copyright_doc' => '&#35814;&#32454;&#20449;&#24687;,&#35831;&#35775;&#38382;&#31449;&#28857; <a href="@spipnet@">http://www.spip.net/zh</a>.', # MODIF
'info_copyright_gpl' => '&#26681;&#25454;GPL&#21327;&#35758;',
'info_cours_edition' => '&#36827;&#23637;&#20013;&#25991;&#31456;',
'info_creer_repertoire' => '&#35831;&#21019;&#24314;&#19968;&#20010;&#25991;&#20214;&#25110;&#30446;&#24405;&#21483;:',
'info_creer_repertoire_2' => '&#22312;<b>@repertoire@</b>&#23376;&#30446;&#24405;&#20869;&#37096;&#65292;&#28982;&#21518;&nbsp;&#65306;',
'info_creer_vignette' => '&#33258;&#21160;&#20135;&#29983;&#22270;&#26631;',
'info_deplier' => '&#23637;&#24320;',
'info_descriptif_nombre' => '&#25551;&#36848;:',
'info_description' => '&#25551;&#36848;:',
'info_description_2' => '&#25551;&#36848;:',
'info_dimension' => '&#22823;&#23567;:',
'info_document' => '&#25991;&#26723;',
'info_document_indisponible' => '<modif>&#26080;&#27861;&#33719;&#24471;&#27492;&#25991;&#20214;',
'info_documents' => '&#25991;&#20214;',
'info_documents_nb' => '@nb@ documents', # NEW
'info_documents_un' => '1 document', # NEW
'info_echange_message' => 'SPIP &#20801;&#35768;&#22312;&#35752;&#35770;&#32773;&#20013;&#20132;&#25442;&#28040;&#24687;&#21644;&#31169;&#26377;&#35752;&#35770;&#35770;&#22363;
  . &#20320;&#21487;&#28608;&#27963;&#25110;
  &#20351;&#36825;&#20010;&#29305;&#24615;&#19981;&#21487;&#29992;.',
'info_ecire_message_prive' => '&#20889;&#19968;&#20010;&#31169;&#26377;&#20449;&#24687;',
'info_email_invalide' => '&#26080;&#35770;&#30005;&#23376;&#37038;&#20214;&#22320;&#22336;.',
'info_en_cours_validation' => '&#36827;&#23637;&#20013;&#30340;&#25991;&#31456;',
'info_en_ligne' => '&#29616;&#22312;&#22312;&#32447;:',
'info_envoyer_message_prive' => '&#32473;&#20316;&#32773;&#21457;&#19968;&#20010;&#31169;&#26377;&#20449;&#24687;',
'info_erreur_requete' => '&#38169;&#35823;&#26597;&#35810;:',
'info_erreur_squelette2' => '&#25152;&#26377;&#38754;&#26495;<b>@fichier@</b>&#22343;&#26080;&#25928;...',
'info_erreur_systeme' => '&#31995;&#32479;&#38169;&#35823; (errno @errsys@)',
'info_erreur_systeme2' => '<MODIF>&#30828;&#30424;&#26080;&#36275;&#22815;&#31354;&#38388;,&#25110;&#25968;&#25454;&#24211;&#36973;&#30772;&#22351;&#12290; <br />
 <font color=\'red\'>&#35831;&#35797;&#29992; <a href=\'@script@\'>&#20462;&#22797;&#25968;&#25454;&#24211;</a>&#65292;
 &#25110;&#32773;&#32852;&#31995;&#24744;&#30340;&#31649;&#29702;&#21592;&#12290;</font>',
'info_fini' => '&#23436;&#25104;&#20102;!',
'info_format_image' => '&#22270;&#29255;&#26684;&#24335;&#34987;&#29992;&#26469;&#21019;&#24314;&#25554;&#22270;: @gd_formats@.',
'info_format_non_defini' => '&#26410;&#23450;&#20041;&#26684;&#24335;',
'info_grand_ecran' => '&#22823;&#22270;&#26174;&#31034;',
'info_image_aide' => '&#24110;&#21161;',
'info_image_process_titre' => '&#29983;&#25104;&#22270;&#26631;&#30340;&#26041;&#27861;',
'info_impossible_lire_page' => '<b>&#38169;&#35823;!</b>&#36890;&#36807;&#20195;&#29702;&#26381;&#21153;&#65292;&#27492;&#39029;&#19981;&#33021;&#38405;&#35835;<tt><html>@test_proxy@</html></tt>',
'info_inclusion_directe' => '&#30452;&#25509;&#21253;&#21547;:',
'info_inclusion_vignette' => '&#21253;&#21547;&#23567;&#25554;&#22270;:',
'info_installation_systeme_publication' => '&#20844;&#20247;&#31995;&#32479;&#23433;&#35013; ...',
'info_installer_documents' => '&#24744;&#21487;&#20197;&#33258;&#21160;&#23433;&#35013; @upload@ &#20013;&#25152;&#26377;&#25991;&#20214;&#12290;',
'info_installer_ftp' => '&#20316;&#20026;&#31649;&#29702;&#21592;&#65292;&#24744;&#21487;&#23433;&#35013;(&#36890;&#36807; FTP)@upload@&#20013;&#25991;&#20214;&#20351;&#24471;&#20197;&#21518;&#33021;&#20174;&#36825;&#20799;&#36873;&#25321;.',
'info_installer_images' => '&#20320;&#21487;&#23433;&#35013;&#30340;&#22270;&#29255;&#26684;&#24335; JPEG, GIF &#21450;&#20854;&#23427; PNG.',
'info_installer_images_dossier' => '&#23433;&#35013;@upload@&#30446;&#24405;&#20013;&#30340;&#22270;&#29255;&#20197;&#20415;&#22312;&#36825;&#37324;&#21487;&#20197;&#36873;&#25321;&#20182;&#20204;&#12290;',
'info_installer_tous_documents' => '&#23433;&#35013;&#25152;&#26377;&#25991;&#26723;',
'info_interface_complete' => '&#23436;&#25972;&#30028;&#38754;',
'info_interface_simple' => '&#31616;&#21333;&#30028;&#38754; ',
'info_joindre_document_article' => '&#20320;&#21487;&#38468;&#19978;&#20320;&#30340;&#25991;&#31456;&#30340;&#38468;&#21152;&#25991;&#26723;&#30340;&#31867;&#22411;',
'info_joindre_document_rubrique' => '&#24744;&#21487;&#21152;&#20837;&#35813;&#26639;&#30340;&#25991;&#26723;&#31867;&#22411;',
'info_joindre_documents_article' => '&#20320;&#21487;&#38468;&#19978;&#20320;&#25991;&#31456;&#30340;&#38468;&#21152;&#25991;&#26723;&#30340;&#31867;&#22411;:',
'info_l_article' => '&#25991;&#31456;',
'info_la_breve' => '&#26032;&#38395;',
'info_la_rubrique' => '&#19987;&#26639;',
'info_langue_principale' => '&#20027;&#31449;&#28857;&#35821;&#35328;',
'info_largeur_vignette' => '@largeur_vignette@ x @hauteur_vignette@ &#20687;&#32032;', # MODIF
'info_les_auteurs_1' => '&#25353; @les_auteurs@',
'info_logo_format_interdit' => '&#20165;@formats@&#26684;&#24335;&#20043;&#25991;&#20214;&#34987;&#20801;&#35768;&#20316;&#26631;&#24535;',
'info_logo_max_poids' => 'Les logos doivent obligatoirement faire moins de @maxi@ (ce fichier fait @actuel@).',
'info_logo_max_taille' => '&#26631;&#24535;&#19981;&#24471;&#36229;&#36807; @maxi@ (&#30446;&#21069;&#30340;&#25991;&#20214;&#22823;&#23567;&#20026;@actuel@).',
'info_mail_fournisseur' => 'you@isp.com',
'info_message_2' => '&#28040;&#24687;',
'info_message_supprime' => '&#21024;&#38500;&#30340;&#28040;&#24687;',
'info_messages_nb' => '@nb@ messages', # NEW
'info_messages_un' => '1 message', # NEW
'info_mise_en_ligne' => '&#22312;&#32447;&#20986;&#29256;&#29289;&#30340;&#26085;&#26399;:',
'info_modification_parametres_securite' => '&#20462;&#25913;&#23433;&#20840;&#21442;&#25968;',
'info_mois_courant' => '&#22312;&#26376;&#20013;:',
'info_mot_cle_ajoute' => '&#19979;&#21015;&#20851;&#38190;&#34987;&#21152;&#36827;',
'info_multi_herit' => '&#32570;&#30465;&#35821;&#35328;',
'info_multi_langues_soulignees' => '<u>&#21152;&#19979;&#21010;&#32447;&#30340;&#35821;&#35328;</u> &#25552;&#20379;&#20102;&#25152;&#26377;&#30028;&#38754;&#30340;&#35821;&#35328;&#30340;&#32763;&#35793;. &#22914;&#26524;&#20320;&#36873;&#25321;&#35821;&#35328;, &#20844;&#20849;&#31449;&#28857;&#30340;&#25152;&#26377;&#20803;&#32032; (&#26085;&#26399;, &#35770;&#22363;) &#23558;&#34987;&#33258;&#21160;&#32763;&#35793;. &#20316;&#20026;&#27809;&#26377;&#19979;&#21010;&#32447;&#30340;&#35821;&#35328;, &#36825;&#20123;&#20803;&#32032;&#23558;&#20986;&#29616;&#22312;&#31449;&#28857;&#30340;&#20027;&#35821;&#35328;&#30028;&#38754;&#19978;.', # MODIF
'info_multilinguisme' => '&#22810;&#35821;&#35328;',
'info_nom_non_utilisateurs_connectes' => '&#20320;&#30340;&#21517;&#23383;&#19981;&#26174;&#31034;&#22312;&#36830;&#25509;&#29992;&#25143;&#30340;&#21015;&#34920;&#20013;.',
'info_nom_utilisateurs_connectes' => '&#20320;&#30340;&#21517;&#23383;&#26174;&#31034;&#22312;&#36830;&#25509;&#29992;&#25143;&#30340;&#21015;&#34920;&#20013;.',
'info_nombre_en_ligne' => '&#29616;&#22312;&#22312;&#32447;:',
'info_non_resultat' => ' "@cherche_mot@"&#27809;&#26377;&#32467;&#26524;',
'info_non_utilisation_messagerie' => '&#20320;&#27809;&#26377;&#20351;&#29992;&#31449;&#28857;&#20869;&#37096;&#28040;&#24687;.',
'info_nouveau_message' => '&#20320;&#26377;&#26032;&#28040;&#24687;',
'info_nouveaux_messages' => '&#20320;&#26377; @total_messages@ &#26465;&#26032;&#28040;&#24687;',
'info_numero_abbreviation' => '&#31532;&nbsp;',
'info_obligatoire' => 'Cette information est obligatoire', # NEW
'info_panne_site_syndique' => '&#32852;&#21512;&#31449;&#28857;&#27425;&#24207;&#39072;&#20498;',
'info_pense_bete' => '&#24536;&#22791;',
'info_petit_ecran' => '&#23567;&#22270;&#26174;&#31034;',
'info_petition_close' => 'P&eacute;tition close', # NEW
'info_pixels' => '&#20687;&#32032;',
'info_plusieurs_mots_trouves' => '&#20960;&#20010;&#20851;&#38190;&#35789;&#25214;&#21040;&#20102; "@cherche_mot@":',
'info_popularite_5' => '&#27969;&#34892;:',
'info_portfolio' => '&#30456;&#20876;',
'info_portfolio_automatique' => '&#33258;&#21160;&#30456;&#20876;:',
'info_premier_resultat' => '[@debut_limit@ &#26368;&#26032;&#32467;&#26524;&#20986;&#20102; @total@]',
'info_premier_resultat_sur' => '[@debut_limit@ &#26368;&#26032;&#32467;&#26524;&#20986;&#20102;@total@]',
'info_probleme_grave' => '&#38169;&#35823;',
'info_propose_1' => '[@nom_site_spip@] &#25552;&#20132;: @titre@',
'info_propose_2' => '&#25552;&#20132;&#25991;&#31456;
-----------------',
'info_propose_3' => '&#25991;&#31456; "@titre@" &#25552;&#20132;&#32473;&#20844;&#20247;.',
'info_propose_4' => '&#20320;&#34987;&#36992;&#35831;&#39044;&#35272;&#23427;&#21457;&#34920;&#20320;&#30340;&#35266;&#24565;',
'info_propose_5' => '&#22312;&#35770;&#22363;&#20013;&#36830;&#21521;&#23427;. &#22312;&#22320;&#22336;&#20013;&#21487;&#29992;&#21040;:',
'info_publie_01' => '&#25991;&#31456; "@titre@" &#34987; @connect_nom@&#30830;&#35748;.',
'info_publie_1' => '[@nom_site_spip@] &#20986;&#29256;: @titre@',
'info_publie_2' => '&#20986;&#29256;&#30340;&#25991;&#31456;
-----------------',
'info_rechercher' => '&#25628;&#32034;',
'info_rechercher_02' => '&#25628;&#32034;:',
'info_remplacer_vignette' => '&#29992;&#23450;&#21046;&#30340;&#22270;&#26631;&#21462;&#20195;&#32570;&#30465;&#30340;&#22270;&#26631;:',
'info_retablir_lien' => '&#24674;&#22797;&#36825;&#20010;&#36830;&#25509;',
'info_retirer_mot' => '&#31227;&#21160;&#36825;&#20010;&#20851;&#38190;&#35789;',
'info_retirer_mots' => '&#31227;&#21435;&#25152;&#26377;&#30340;&#20851;&#38190;&#35789;',
'info_rubriques_nb' => '@nb@ rubriques', # NEW
'info_rubriques_un' => '1 rubrique', # NEW
'info_sans_titre_2' => '&#26080;&#26631;&#39064;',
'info_selectionner_fichier' => '<MODIF>&#20174;@upload@&#25991;&#20214;&#20013;&#36873;&#25321;&#19968;&#20010;&#25991;&#20214;',
'info_selectionner_fichier_2' => '&#36873;&#25321;&#19968;&#20010;&#25991;&#20214;:',
'info_signature_supprimee' => 'Signature supprim&eacute;e', # NEW
'info_signature_supprimee_erreur' => 'Erreur&nbsp;: ce code de suppression ne correspond a aucune signature', # NEW
'info_site_attente' => '&#26410;&#30830;&#35748;&#30340;&#31449;&#28857;',
'info_site_reference' => '&#22312;&#32447;&#24341;&#29992;&#30340;&#31449;&#28857;',
'info_site_refuse' => '&#20002;&#24323;&#30340;&#31449;&#28857;',
'info_sites_nb' => '@nb@ sites', # NEW
'info_sites_referencer' => '&#21442;&#32771;&#31449;&#28857;',
'info_sites_un' => '1 site', # NEW
'info_supprimer_vignette' => '&#21024;&#38500;&#23567;&#25554;&#22270;',
'info_symbole_bleu' => '<MODIF><b>&#34013;&#33394;</b>&#26631;&#24535;<b>&#22791;&#27880;</b>&#65306;&#20363;&#22914;&#20010;&#20154;&#20351;&#29992;&#30340;&#28040;&#24687;.',
'info_symbole_jaune' => '<MODIF><b>&#40644;&#33394;</b>&#34920;&#31034;<b>&#23545;&#25152;&#26377;&#32534;&#36753;&#32773;&#22768;&#26126;</b>&nbsp;&#65306;&#25152;&#26377;&#31449;&#28857;&#31649;&#29702;&#32773;&#37117;&#33021;&#30475;&#35265;&#24182;&#32534;&#36753;&#12290;',
'info_symbole_vert' => '<MODIF><b>&#32511;&#33394;</b>&#34920;&#31034;<b>&#31449;&#28857;&#20013;&#19982;&#20854;&#23427;&#29992;&#25143;&#20132;&#25442;&#30340;&#20449;&#24687;</b>&#12290;',
'info_syndication' => '<MODIF>&#32858;&#21512;&nbsp;&#65306;',
'info_syndication_articles' => '&#25991;&#31456;',
'info_telecharger' => '&#20174;&#20320;&#30340;&#30005;&#33041;&#19978;&#20256;:',
'info_telecharger_nouveau_logo' => '&#19978;&#20256;&#26032;&#22270;&#26631;:',
'info_telecharger_ordinateur' => '&#20174;&#20320;&#30340;&#30005;&#33041;&#19978;&#20256;:',
'info_tous_resultats_enregistres' => '[&#25152;&#26377;&#32467;&#26524;&#34987;&#35760;&#24405;]',
'info_tout_afficher' => '&#26174;&#31034;&#25152;&#26377;',
'info_travaux_texte' => '&#31449;&#28857;&#36824;&#26410;&#24314;&#31435;. &#35831;&#31245;&#21518;&#20877;&#26469;...',
'info_travaux_titre' => '&#31449;&#28857;&#27491;&#22312;&#26045;&#24037;&#20013;',
'info_trop_resultat' => ' "@cherche_mot@"&#26377;&#22826;&#22810;&#32467;&#26524;; &#35831;&#37325;&#23450;&#20041;&#25628;&#32034;.',
'info_utilisation_messagerie_interne' => '&#20320;&#27491;&#20351;&#29992;&#31449;&#28857;&#30340;&#20869;&#37096;&#28040;&#24687;.',
'info_valider_lien' => '&#20351;&#36830;&#25509;&#26377;&#25928;',
'info_verifier_image' => ', &#35831;&#30830;&#23450;&#20320;&#30340;&#22270;&#29255;&#24050;&#27491;&#30830;&#20256;&#36865;.',
'info_vignette_defaut' => '&#32570;&#30465;&#30340;&#23567;&#25554;&#22270;',
'info_vignette_personnalisee' => '&#23450;&#21046;&#23567;&#25554;&#22270;',
'info_visite' => '&#35775;&#38382;:',
'info_visites' => '&#35775;&#38382;:',
'info_vos_rendez_vous' => '&#23558;&#26469;&#30340;&#32422;&#20250;',
'info_zoom' => '&#32553;&#25918;',
'infos_vos_pense_bete' => '&#22791;&#27880;',
'item_breve_proposee' => '&#26032;&#38395;&#25552;&#20132;',

// L
'lien_afficher_icones_seuls' => '&#21482;&#26174;&#31034;&#22270;&#29255;',
'lien_afficher_texte_icones' => '&#26174;&#31034;&#25991;&#26412;&#21644;&#22270;&#29255;',
'lien_afficher_texte_seul' => '&#21482;&#26174;&#31034;&#27491;&#25991;',
'lien_liberer' => '&#21457;&#34920;',
'lien_liberer_tous' => '&#37322;&#25918;&#36825;&#20123;&#25991;&#31456;',
'lien_nouvea_pense_bete' => '&#26032;&#22791;&#27880;',
'lien_nouveau_message' => '&#26032;&#28040;&#24687;',
'lien_nouvelle_annonce' => '&#26032;&#22768;&#26126;',
'lien_petitions' => '&#35831;&#27714;',
'lien_popularite' => '&#26222;&#21450;: @popularite@%',
'lien_racine_site' => '&#31449;&#28857;&#26681;',
'lien_reessayer' => '&#37325;&#35797;',
'lien_repondre_message' => '&#22238;&#24212;&#28040;&#24687;',
'lien_supprimer' => '&#21024;&#38500;',
'lien_tout_afficher' => '&#26174;&#31034;&#25152;&#26377;',
'lien_visite_site' => '&#35775;&#38382;&#31449;&#28857;',
'lien_visites' => '@visites@ &#35775;&#38382;',
'lien_voir_auteur' => '&#26816;&#26597;&#20316;&#32773;',
'ligne' => 'Ligne', # NEW
'login' => 'Connexion', # NEW
'login_acces_prive' => '&#35775;&#38382;&#31169;&#26377;&#21306;',
'login_autre_identifiant' => '&#29992;&#21478;&#19968;&#20010;&#26631;&#35782;&#31526;',
'login_cookie_accepte' => '&#35831;&#35774;&#23450;&#20320;&#30340;&#27983;&#35272;&#22120;&#25509;&#21463;&#23427;&#20204; (&#33267;&#23569;&#26159;&#36825;&#20010;&#31449;&#28857;a).',
'login_cookie_oblige' => '&#20026;&#23433;&#20840;&#30340;&#26631;&#35782;&#20320;,&#20320;&#24517;&#39035;&#25509;&#21463;cookies.',
'login_deconnexion_ok' => '&#24050;&#26029;&#24320;&#36830;&#25509;.',
'login_erreur_pass' => '&#23494;&#30721;&#38169;.',
'login_espace_prive' => '&#31169;&#26377;&#21306;',
'login_identifiant_inconnu' => '&#26631;&#35782;&#31526; "@login@" &#19981;&#21487;&#35748;.',
'login_login' => '&#30331;&#24405;:',
'login_login2' => '&#30331;&#24405;(&#36830;&#25509;&#21040;&#31449;&#28857;&#30340;&#26631;&#35782;&#31526;):',
'login_login_pass_incorrect' => '(&#38169;&#35823;&#30340;&#30331;&#24405;&#21644;&#23494;&#30721;).',
'login_motpasseoublie' => '&#24536;&#35760;&#23494;&#30721;?',
'login_non_securise' => '&#35686;&#21578;, &#35770;&#22363;&#19981;&#23433;&#20840;.
   &#22914;&#26524;&#20320;&#19981;&#24895;&#33258;&#24049;&#30340;&#23494;&#30721;&#20013;&#36884;&#20390;&#21548;&#21040;
   , &#35831;&#28608;&#27963;&#20320;&#27983;&#35272;&#22120;&#30340; Javascript
   &#24182;&#19988;',
'login_nouvelle_tentative' => '&#26032;&#23581;&#35797;',
'login_par_ici' => '&#20320;&#24050;&#27880;&#20876;... &#36825;&#31181;&#26041;&#27861;...',
'login_pass2' => '&#23494;&#30721;:',
'login_preferez_refuser' => '<b>&#22914;&#26524;&#20320;&#26356;&#24895;&#24847;&#25298;&#32477; cookies</b>, &#26377;&#20854;&#23427;&#30340;&#36830;&#25509;&#26041;&#27861; (&#23433;&#20840;&#24615;&#35201;&#20302;&#19968;&#20123;) :',
'login_recharger' => '&#37325;&#36733;&#35813;&#39029;',
'login_rester_identifie' => '&#20445;&#30041;&#30331;&#24405;&#20960;&#22825;',
'login_retour_public' => '&#36820;&#22238;&#20844;&#20849;&#31449;&#28857;',
'login_retour_site' => '&#36820;&#22238;&#20844;&#20849;&#31449;&#28857;',
'login_retoursitepublic' => '&#36820;&#22238;&#20844;&#20849;&#31449;&#28857;',
'login_sans_cookiie' => '&#26080;COOKIE&#30340;&#26631;&#35782;',
'login_securise' => 'Login s&eacute;curis&eacute;', # NEW
'login_sinscrire' => '&#27880;&#20876;',
'login_test_navigateur' => '&#27979;&#35797;&#27983;&#35272;/&#37325;&#26032;&#36830;&#25509;',
'login_verifiez_navigateur' => '(&#26080;&#35770;&#22914;&#20309;, &#35831;&#30830;&#35748;&#20320;&#30340;&#27983;&#35272;&#22120;&#19981;&#20250;&#35760;&#20303;&#20320;&#30340;&#23494;&#30721;...)',

// M
'masquer_colonne' => 'Masquer cette colonne', # NEW
'masquer_trad' => 'masquer les traductions', # NEW
'module_fichiers_langues' => '&#35821;&#35328;&#25991;&#20214;',

// N
'navigateur_pas_redirige' => '&#22914;&#26524;&#24744;&#30340;&#27983;&#35272;&#22120;&#27809;&#26377;&#36339;&#36716;,&#35831;&#25353;&#36825;&#37324;&#32487;&#32493;.',
'numero' => 'Num&eacute;ro', # NEW

// O
'occurence' => 'Occurrence', # NEW
'onglet_affacer_base' => '&#21024;&#38500;&#25968;&#25454;&#24211;',
'onglet_auteur' => '&#20316;&#32773;',
'onglet_contenu_site' => '&#31449;&#28857;&#20869;&#23481;',
'onglet_evolution_visite_mod' => '&#35780;&#20272;',
'onglet_fonctions_avances' => '&#39640;&#32423;&#21151;&#33021;',
'onglet_informations_personnelles' => '&#20010;&#20154;&#20449;&#24687;',
'onglet_interactivite' => '&#20114;&#21160;',
'onglet_messagerie' => '&#28040;&#24687;',
'onglet_messages_internes' => '&#20869;&#23481;&#28040;&#24687;',
'onglet_messages_publics' => '&#20844;&#20247;&#28040;&#24687;',
'onglet_messages_vide' => '&#26080;&#25991;&#23383;&#28040;&#24687;',
'onglet_origine_visites' => '&#35775;&#38382;&#32773;&#36215;&#28304;',
'onglet_repartition_debut' => '&#20174;&#24320;&#22987;',
'onglet_repartition_lang' => '<MODIF>&#26681;&#25454;&#35821;&#35328;&#37325;&#26032;&#20998;&#24067;',
'onglet_repartition_rubrique' => '&#25353;&#19987;&#26639;&#21457;&#24067;',
'onglet_save_restaur_base' => '&#22791;&#20221;/&#24674;&#22797;&#25968;&#25454;&#24211;',
'onglet_vider_cache' => '&#28165;&#31354;&#32531;&#23384;',
'ortho_trop_de_fautes2' => '&#35831;&#20462;&#25913;&#26368;&#26126;&#26174;&#30340;&#38169;&#35823;&#65292;&#28982;&#21518;&#20877;&#35797;&#12290;',

// P
'pass_choix_pass' => '&#35831;&#36873;&#25321;&#26032;&#23494;&#30721;:',
'pass_erreur' => '&#38169;&#35823;',
'pass_erreur_acces_refuse' => '<b>&#38169;&#35823;:</b> &#20320;&#20877;&#20063;&#26080;&#26435;&#35775;&#38382;&#31449;&#28857;.',
'pass_erreur_code_inconnu' => '<b>&#38169;&#35823;:</b> &#20195;&#30721;&#19981;&#31526;&#21512;&#20219;&#20309;&#26377;&#31449;&#28857;&#35775;&#38382;&#26435;&#30340;&#35775;&#38382;&#32773;.',
'pass_erreur_non_enregistre' => '<b>&#38169;&#35823; :</b> &#22320;&#22336;<tt>@email_oubli@</tt> &#26410;&#22312;&#31449;&#28857;&#27880;&#20876;.',
'pass_erreur_non_valide' => '<b>&#38169;&#35823; :</b> &#30005;&#23376;&#37038;&#20214; <tt>@email_oubli@</tt> &#26080;&#25928;!',
'pass_erreur_probleme_technique' => '<b>&#38169;&#35823; :</b> &#30005;&#23376;&#37038;&#20214;&#30001;&#20110;&#25216;&#26415;&#21407;&#22240;&#19981;&#33021;&#21457;&#36865;.',
'pass_espace_prive_bla' => '&#27880;&#20876;&#21518;&#31449;&#28857;&#30340;&#31169;&#26377;&#21306;&#23545;&#35775;&#38382;&#32773;&#24320;&#25918;
. &#19968;&#26086;&#27880;&#20876;,
&#20320;&#21487;&#20197;&#39044;&#35272;&#36827;&#23637;&#20013;&#30340;&#25991;&#31456;,
&#25552;&#20132;&#25991;&#31456;&#21442;&#19982;&#25152;&#26377;&#30340;&#35770;&#22363;.',
'pass_forum_bla' => '&#20320;&#24050;&#35831;&#27714;&#21442;&#19982;&#35770;&#22363;
&#27880;&#20876;&#35775;&#38382;&#32773;&#20445;&#30041;&#21306;.',
'pass_indiquez_cidessous' => '&#22312;&#20197;&#19979;&#36755;&#20837;&#20320;&#20197;&#21069;&#27880;&#20876;&#30340;&#30005;&#23376;&#37038;&#20214;&#22320;&#22336;
.&#20320;
&#23558;&#25910;&#21040;&#30005;&#23376;&#37038;&#20214;
&#21521;&#20320;&#35299;&#37322;&#22914;&#20309;&#24471;&#21040;&#35775;&#38382;.',
'pass_mail_passcookie' => '<MODIF>(&#36825;&#26159;&#33258;&#21160;&#28040;&#24687;)
&#35201;&#37325;&#26032;&#35775;&#38382;&#31449;&#28857;
@nom_site_spip@ (@adresse_site@)

&#35831;&#21040;&#20197;&#19979;&#22320;&#22336;:

    @sendcookie@

&#24744;&#21487;&#20197;&#36755;&#20837;&#26032;&#23494;&#30721;
&#37325;&#26032;&#36830;&#25509;&#21040;&#31449;&#28857;&#12290;

',
'pass_mot_oublie' => '&#24536;&#35760;&#23494;&#30721;',
'pass_nouveau_enregistre' => '&#20320;&#30340;&#26032;&#23494;&#30721;&#24050;&#32463;&#34987;&#35760;&#24405;.',
'pass_nouveau_pass' => '&#26032;&#23494;&#30721;',
'pass_ok' => '&#22909;',
'pass_oubli_mot' => '&#24536;&#35760;&#23494;&#30721;',
'pass_quitter_fenetre' => '&#36864;&#20986;&#31383;&#21475;',
'pass_rappel_login' => '&#35760;&#20303;: &#20320;&#30340;&#26631;&#35782;&#31526;(&#30331;&#24405;) &#26159; "@login@".',
'pass_recevoir_mail' => '&#20320;&#23558;&#25910;&#21040;&#30005;&#23376;&#37038;&#20214;&#35299;&#37322;&#22914;&#20309;&#35775;&#38382;&#31449;&#28857;.',
'pass_retour_public' => '&#36820;&#22238;&#20844;&#20247;&#31449;&#28857;',
'pass_rien_a_faire_ici' => '&#36825;&#37324;&#26080;&#20107;&#21487;&#20316;.',
'pass_vousinscrire' => '&#30331;&#35760;&#31449;&#28857;',
'precedent' => '&#21069;&#19968;&#20010;',
'previsualisation' => '&#39044;&#35272;',
'previsualiser' => '&#39044;&#35272;',

// R
'retour' => 'Retour', # NEW

// S
'spip_conforme_dtd' => 'SPIP consid&egrave;re ce document comme conforme &agrave; son DOCTYPE :', # NEW
'squelette' => 'squelette', # NEW
'squelette_inclus_ligne' => 'squelette inclus, ligne', # NEW
'squelette_ligne' => 'squelette, ligne', # NEW
'stats_visites_et_popularite' => '@visites@ &#35775;&#38382;&#32773;; &#27969;&#34892;: @popularite@',
'suivant' => '&#21518;&#19968;&#20010;',

// T
'taille_ko' => '@taille@&nbsp;kb',
'taille_mo' => '@taille@&nbsp;Mb',
'taille_octets' => '@taille@&#23383;&#31526;',
'texte_actualite_site_1' => '<MODIF>&#24403;&#24744;&#35748;&#20026;&#27492;&#30028;&#38754;&#36866;&#21512;&#24744;&#65292;&#24744;&#23601;&#21487;&#20197;&#28857;&#20987;&laquo;',
'texte_actualite_site_2' => '&#23436;&#25972;&#30028;&#35199;',
'texte_actualite_site_3' => '&raquo; &#20351;&#26356;&#22810;&#29305;&#24615;&#21487;&#29992;.',
'texte_creation_automatique_vignette' => '&#31449;&#28857;&#33258;&#21160;&#21019;&#24314;&#31614;&#21517;&#39044;&#35272;&#28608;&#27963;. &#22914;&#26524;&#20320;&#23433;&#35013;, &#36890;&#36807;&#35770;&#22363;, &#22270;&#29255;&#26684;&#24335; @gd_formats@, &#23427;&#20204;&#23558;&#33021;&#21644;&#19968;&#20010;&#26368;&#22823;&#23610;&#23544;&#20026; @taille_preview@ &#20687;&#32032;&#30340;&#36830;&#25509;.',
'texte_documents_associes' => '&#20197;&#19979;&#25991;&#26723;&#19982;&#25991;&#31456;&#30456;&#20851;&#32852;,,
    &#20294;&#26159;&#23427;&#20204;&#19981;&#26159;&#30452;&#25509;&#25554;&#20837;&#30340;
    . &#22522;&#20110;&#20844;&#20849;&#31449;&#28857;&#30340;&#35268;&#21010;,
    &#23427;&#20204;&#23558;&#20316;&#20026;&#38468;&#21644;&#25991;&#26723;&#20986;&#29616;.',
'texte_erreur_mise_niveau_base' => '<MODIF>&#25972;&#29702;&#36807;&#31243;&#20013;&#25968;&#25454;&#24211;&#38169;&#35823;&#12290;
&#22270;&#20687;<b>@fichier@</b>&#19981;&#33021;&#36890;&#36807; (article @id_article@)&#12290;
&#35748;&#30495;&#38405;&#35835;&#27492;&#21442;&#32771;&#20869;&#23481;&#65292;
&#20877;&#35797;&#25972;&#29702;&#36807;&#31243;&#65292;
&#24182;&#27880;&#24847;&#22270;&#20687;&#22987;&#32456;&#26174;&#31034;&#22312;&#20320;&#30340;&#25991;&#20214;&#20013;&#12290;',
'texte_erreur_visiteur' => 'Vous avez tent&eacute; d\'acc&eacute;der &agrave; l\'espace priv&eacute; avec un login qui ne le permet pas.', # NEW
'texte_inc_auth_1' => '&#29992;&#30331;&#24405;&#21517;&#26631;&#35782;&#20320;&#33258;&#24049;
  <b>@auth_login@</b>, &#20294;&#26159;&#22312;&#25968;&#25454;&#24211;&#20013;&#19981;&#23384;&#22312; (&#19981;&#20877;&#23384;&#22312;). 
  &#35797;', # MODIF
'texte_inc_auth_2' => '&#37325;&#26032;&#36830;&#25509;',
'texte_inc_auth_3' => '&#36864;&#20986;&#28982;&#21518;
  &#37325;&#26032;&#21551;&#21160;&#20320;&#30340;&#27983;&#35272;&#22120;.',
'texte_inc_config' => '&#20197;&#19979;&#30340;&#36755;&#20837;&#30340;&#20462;&#25913;&#26174;&#33879;&#30340;&#24433;&#21709;&#20102;&#31449;&#28857;&#30340;&#21151;&#33021;
  . &#20180;&#32454;&#23427;&#38500;&#38750;&#20320;&#29087;&#24713;SPIP&#31995;&#32479;&#30340;&#21151;&#33021;
  . <br /><br /><b>&#26356;&#19968;&#33324;&#22320;
 , &#24378;&#28872;&#24314;&#35758;&#20320;&#30340;WEB&#31449;&#28857;&#31649;&#29702;&#21592;
 &#22788;&#29702;&#36825;&#39029;.</b>', # MODIF
'texte_inc_meta_1' => '&#31995;&#32479;&#20877;&#20889;&#20837;&#25991;&#20214;<code>@fichier@</code>&#26102;&#36935;&#21040;&#38169;&#35823;&#12290;&#20316;&#20026;&#31449;&#28857;&#31649;&#29702;&#21592;&#35831;', # MODIF
'texte_inc_meta_2' => '&#30830;&#35748;&#20889;&#26435;&#38480;', # MODIF
'texte_inc_meta_3' => '&#30446;&#24405; ecrire/ &#20043;&#19978;', # MODIF
'texte_statut_en_cours_redaction' => '&#32534;&#36753;&#20013;',
'texte_statut_poubelle' => '&#21040;&#22403;&#22334;&#31665;',
'texte_statut_propose_evaluation' => '&#25552;&#20132;&#35780;&#20272;',
'texte_statut_publie' => '&#22312;&#32447;&#20986;&#29256;',
'texte_statut_refuse' => '&#20002;&#24323;',
'titre_ajouter_mot_cle' => '&#21152;&#20851;&#38190;&#23383;:',
'titre_breve_proposee' => '&#25552;&#20132;&#30340;&#26032;&#38395;',
'titre_breve_publiee' => '&#21457;&#34920;&#30340;&#26032;&#38395;',
'titre_breve_refusee' => '&#20002;&#24323;&#30340;&#26032;&#38395;',
'titre_cadre_raccourcis' => '&#24555;&#25463;&#26041;&#24335;:',
'titre_changer_couleur_interface' => '&#25913;&#21464;&#30028;&#38754;&#39068;&#33394;',
'titre_forum' => '&#20869;&#37096;&#35770;&#22363;',
'titre_image_admin_article' => '&#20320;&#21487;&#20197;&#31649;&#29702;&#36825;&#31687;&#25991;&#31456;',
'titre_image_administrateur' => '&#31649;&#29702;&#32773;',
'titre_image_aide' => '&#35813;&#39033;&#30446;&#30340;&#24110;&#21161;',
'titre_image_auteur_supprime' => '&#21024;&#38500;&#30340;&#20316;&#32773;',
'titre_image_redacteur' => '&#19981;&#33021;&#35775;&#38382;&#30340;&#32534;&#36753;&#32773;',
'titre_image_redacteur_02' => '&#32534;&#36753;&#32773;',
'titre_image_visiteur' => '&#35775;&#38382;&#32773;',
'titre_joindre_document' => '&#38468;&#21152;&#25991;&#26723;',
'titre_liens_entrants' => '&#35775;&#38382;&#38142;&#25509;', # MODIF
'titre_mots_cles' => '&#20851;&#38190;&#35789;',
'titre_probleme_technique' => '&#35686;&#21578;:&#25216;&#26415;&#38382;&#39064; MYSQL &#21046;&#27490;&#35775;&#38382;&#31449;&#28857;&#30340;&#36825;&#37096;&#20998;,&#35874;&#35874;&#29702;&#35299; .', # MODIF
'titre_publier_document' => '&#22312;&#27492;&#26639;&#19979;&#21457;&#24067;&#25991;&#26723;',
'titre_signatures_attente' => '<modif>&#31614;&#21517;&#31561;&#24453;&#35748;&#35777;',
'titre_signatures_confirmees' => 'Signatures confirm&eacute;es', # NEW
'titre_statistiques' => '&#31449;&#28857;&#32479;&#35745;',
'titre_titre_document' => '&#25991;&#31456;&#26631;&#39064;:',
'todo' => '&agrave; venir', # NEW
'trad_reference' => '(&#21442;&#32771;&#25991;&#31456;)',

// Z
'zbug_balise_b_aval' => '&nbsp;: balise B en aval', # NEW
'zbug_balise_inexistante' => 'erreur @from@: la balise #@balise@ n\'existe pas', # MODIF
'zbug_balise_sans_argument' => 'Argument manquant dans la balise @balise@', # NEW
'zbug_boucle' => 'boucle', # NEW
'zbug_boucle_recursive_undef' => 'boucle r&eacute;cursive non d&eacute;finie', # MODIF
'zbug_calcul' => 'calcul', # NEW
'zbug_champ_hors_boucle' => 'Champ @champ@ hors boucle', # NEW
'zbug_champ_hors_motif' => 'Champ @champ@ hors d\'une boucle de motif @motif@', # MODIF
'zbug_code' => '&#20195;&#30721;',
'zbug_critere_inconnu' => 'crit&egrave;re inconnu @critere@', # MODIF
'zbug_distant_interdit' => 'externe interdit', # MODIF
'zbug_doublon_table_sans_cle_primaire' => 'doublons sur une table sans clef primaire atomique', # MODIF
'zbug_doublon_table_sans_index' => 'doublons sur une table sans index', # MODIF
'zbug_erreur_boucle_double' => '&#29615;@id@: &#37325;&#22797;&#23450;&#20041;', # MODIF
'zbug_erreur_boucle_fermant' => '&#29615;@id@: &#32570;&#23569;&#35821;&#21477;&#32467;&#23614;&#26631;&#24535;', # MODIF
'zbug_erreur_boucle_syntaxe' => '&#21477;&#27861;&#20013;&#20986;&#29616;&#38169;&#35823;&#30340;&#29615;', # MODIF
'zbug_erreur_compilation' => 'Erreur de compilation', # NEW
'zbug_erreur_execution_page' => 'erreur d\'ex&eacute;cution de la page', # MODIF
'zbug_erreur_filtre' => '&#38169;&#35823;: &#36807;&#28388;<b>&laquo; @filtre@ &raquo;</b>&#26410;&#23450;&#20041;', # MODIF
'zbug_erreur_meme_parent' => '{meme_parent} ne s\'applique qu\'aux boucles (FORUMS) ou (RUBRIQUES)', # MODIF
'zbug_erreur_squelette' => 'Erreur(s) dans le squelette', # NEW
'zbug_hors_compilation' => 'Hors Compilation', # NEW
'zbug_info_erreur_squelette' => '&#31449;&#28857;&#38169;&#35823;',
'zbug_inversion_ordre_inexistant' => 'inversion d\'un ordre inexistant', # MODIF
'zbug_pagination_sans_critere' => '#PAGINATION sans crit&egrave;re {pagination} ou employ&eacute; dans une boucle recursive', # MODIF
'zbug_parametres_inclus_incorrects' => 'Param&egrave;tres d\'inclusion incorrects', # MODIF
'zbug_profile' => 'Temps de calcul&nbsp;: @time@', # NEW
'zbug_resultat' => 'r&eacute;sultat', # NEW
'zbug_serveur_indefini' => 'serveur SQL ind&eacute;fini', # MODIF
'zbug_statistiques' => 'Statistiques des requ&ecirc;tes SQL class&eacute;es par dur&eacute;e', # NEW
'zbug_table_inconnue' => 'SQL&#34920;&#26684; &laquo; @table@ &raquo; &#26410;&#30693;',
'zxml_connus_attributs' => 'attributs connus', # NEW
'zxml_de' => 'de', # NEW
'zxml_inconnu_attribut' => 'attribut inconnu', # NEW
'zxml_inconnu_balise' => 'balise inconnue', # NEW
'zxml_inconnu_entite' => 'entit&eacute; inconnue', # NEW
'zxml_inconnu_id' => 'ID inconnu', # NEW
'zxml_mais_de' => 'mais de', # NEW
'zxml_non_conforme' => 'n\'est pas conforme au motif', # NEW
'zxml_non_fils' => 'n\'est pas un fils de', # NEW
'zxml_nonvide_balise' => 'balise non vide', # NEW
'zxml_obligatoire_attribut' => 'attribut obligatoire mais absent dans', # NEW
'zxml_succession_fils_incorrecte' => 'succession des fils incorrecte', # NEW
'zxml_survoler' => 'survoler pour voir les corrects', # NEW
'zxml_valeur_attribut' => 'valeur de l\'attribut', # NEW
'zxml_vide_balise' => 'balise vide', # NEW
'zxml_vu' => 'vu auparavant', # NE
);

?>
